from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from globals import Global
from model.qtmodels.group_table_model import GroupTableModel
from model.qtmodels.person_table_model import PersonTableModel
from windows import groupsoverview


class GroupsOverview(QWidget, groupsoverview.Ui_Form):
    _BUTTON_WIDTH = 50

    _editButtonsMembers = []
    _editButtonsGroup = []

    def __init__(self, main_window, parent=None):
        super(GroupsOverview, self).__init__(parent)
        self.main_window = main_window
        self.setupUi(self)
        #self.btnCreateGroup.clicked.connect()
        self._initializeGroupsTable()
        self._initializeMembersTable()

    # initializes groups table (sets column widths, signals, etc.)
    def _initializeGroupsTable(self):

        # initialize content
        model = GroupTableModel(Global.db.getGroups(), 2)
        self.tableGroups.setModel(model)
        for i in range(model.rowCount()):
            edit_button = QPushButton("edit")
            self._editButtonsGroup.append(edit_button)
            edit_button.clicked.connect(self.editGroup)
            self.tableGroups.setIndexWidget(model.index(i, 1), edit_button)
        model.dataChanged.connect(self.nameButtonsGroup)

        # initialize table settings (and signals)
        header_view = self.tableGroups.horizontalHeader()
        header_view.setSectionResizeMode(0, QHeaderView.Stretch)
        header_view.resizeSection(1, self._BUTTON_WIDTH)
        self.tableGroups.clicked.connect(self.showMembers)
        self.tableGroups.activated.connect(self.showMembers)

        # this also calls nameButtonsGroup() (so the buttons will be correctly named)
        # if for some reason you want to remove this, call self.nameButtonsGroup()
        self.tableGroups.sortByColumn(0, Qt.AscendingOrder)

    # sets object name of every button to id of group on given row
    # also slot for signal 'dataChanged', because buttons do not move when sorting table (we just change their names)
    def nameButtonsGroup(self):
        model = self.tableGroups.model()
        for i, button in enumerate(self._editButtonsGroup):
            group = model.data(model.index(i, 0), model.MODEL_ROLE)
            button.setObjectName(str(group.id))

    # initializes members table (sets column widths, signals, etc.)
    def _initializeMembersTable(self):
        model = PersonTableModel(num_columns=3)
        self.tableMembers.setModel(model)
        header_view = self.tableMembers.horizontalHeader()
        header_view.setSectionResizeMode(0, QHeaderView.Stretch)
        header_view.setSectionResizeMode(1, QHeaderView.Stretch)
        header_view.resizeSection(2, self._BUTTON_WIDTH)

    # sets object name of every button to id of user on given row
    # also slot for signal 'dataChanged', because buttons do not move when sorting table (we just change their names)
    def nameButtonsMembers(self):
        model = self.tableMembers.model()
        for i, button in enumerate(self._editButtonsMembers):
            member = model.data(model.index(i, 0), model.MODEL_ROLE)
            button.setObjectName(str(member.id))

    # changes content of members table to correspond with groups table selection
    def showMembers(self):
        index = self.tableGroups.currentIndex()
        groups = self.tableGroups.model()
        group = groups.data(index, GroupTableModel.MODEL_ROLE)
        members = group.getMembers()
        model = PersonTableModel(members, 3)
        self.tableMembers.setModel(model)
        self._editButtonsMembers = []
        for i in range(model.rowCount()):
            edit_button = QPushButton("edit")
            self._editButtonsMembers.append(edit_button)
            edit_button.clicked.connect(self.editMember)
            self.tableMembers.setIndexWidget(model.index(i, 2), edit_button)
        model.dataChanged.connect(self.nameButtonsMembers)
        # this also calls nameButtonsMembers() (so the buttons will be correctly named)
        # if for some reason you want to remove this, call self.nameButtonsMembers()
        self.tableMembers.sortByColumn(0, Qt.AscendingOrder)

    def editGroup(self):
        print(self.sender().objectName())
        self.main_window.goToGroupEdit(self.sender().objectName())

    def editMember(self):
        print(self.sender().objectName())