from PyQt5 import QtGui, QtCore, uic
from PyQt5.QtWidgets import QPushButton


class GroupTableModel(QtCore.QAbstractTableModel):
    MODEL_ROLE = -1

    def __init__(self, groups=[], num_columns=1, parent=None):
        super(GroupTableModel, self).__init__(parent)
        self._groups = groups
        self._columns = num_columns

    def rowCount(self, parent=None, *args, **kwargs):
        return len(self._groups)

    def columnCount(self, parent=None, *args, **kwargs):
        return self._columns

    def headerData(self, p_int, Qt_Orientation, role=None):
        if role == QtCore.Qt.DisplayRole and p_int == 0:
            return 'Název skupiny'

    def data(self, index, role=None):
        if role == QtCore.Qt.DisplayRole:
            if index.column() == 0:
                return self._groups[index.row()].name

        if role == GroupTableModel.MODEL_ROLE:
            return self._groups[index.row()]

    def sort(self, p_int, order=None):
        if p_int != 0:
            return
        if order == QtCore.Qt.AscendingOrder:
            self._groups.sort(key=lambda group: group.name)
        if order == QtCore.Qt.DescendingOrder:
            self._groups.sort(key=lambda group: group.name, reverse=True)
        self.dataChanged.emit(self.index(0, 0),
                         self.index(self.rowCount(), 0),
                         [])
