from PyQt5 import QtGui, QtCore, uic


class PersonTableModel(QtCore.QAbstractTableModel):
    MODEL_ROLE = -1

    def __init__(self, people=[], num_columns=2, parent=None):
        super(PersonTableModel, self).__init__(parent)
        self._people = people
        self._columns = num_columns

    def rowCount(self, parent=None, *args, **kwargs):
        return len(self._people)

    def columnCount(self, parent=None, *args, **kwargs):
        return self._columns

    def headerData(self, p_int, Qt_Orientation, role=None):
        if role == QtCore.Qt.DisplayRole:
            if p_int == 0:
                return 'Příjmení'
            if p_int == 1:
                return 'Jméno'


    def data(self, index, role=None):
        person = self._people[index.row()]
        if role == QtCore.Qt.DisplayRole:
            if index.column() == 0:
                return person.surname
            if index.column() == 1:
                return person.name

        if role == PersonTableModel.MODEL_ROLE:
            return self._people[index.row()]

    def sort(self, p_int, order=None):
        if p_int > 1:
            return

        #sorting by surname
        if p_int == 0:
            if order == QtCore.Qt.AscendingOrder:
                self._people.sort(key=lambda person: person.surname)
            if order == QtCore.Qt.DescendingOrder:
                self._people.sort(key=lambda person: person.surname, reverse=True)

        #sorting by name
        if p_int == 0:
            if order == QtCore.Qt.AscendingOrder:
                self._people.sort(key=lambda person: person.name)
            if order == QtCore.Qt.DescendingOrder:
                self._people.sort(key=lambda person: person.name, reverse=True)

        self.dataChanged.emit(self.index(0, 0),
                         self.index(self.rowCount(), 0),
                         [])
